@@ -9,15 +9,17 @@
 from .__version__ import __version__
 from .featurewiz import featurewiz, convert_all_object_columns_to_numeric
 from .featurewiz import split_one_field_into_many, add_aggregate_primitive_features
-from .featurewiz import create_time_series_features
+from .featurewiz import fe_create_time_series_features
+################################################################################
 if __name__ == "__main__":
-    version_number = __version__
-    print("""Running featurewiz version: %s. Call by using:
-                 features = featurewiz(dataname, target, corr_limit=0.70,
-                                verbose=2, sep=',', header=0)""" %version_number)
+    module_type = 'Running'
 else:
-    version_number = __version__
-    print("""Imported featurewiz version: %s. Call by using:
-                 features = featurewiz(dataname, target, corr_limit=0.70,
-                                verbose=2,  sep=',', header=0)""" %version_number)
+    module_type = 'Imported'
+version_number = __version__
+print("""%s featurewiz: Auto_ViML's feature engg and selection library. Version=%s
+output = featurewiz(dataname, target, corr_limit=0.70,
+                    verbose=2, sep=',', header=0, test_data='',
+                    feature_engg='', category_encoders='')
+Let featurewiz add features to your data! Set 'feature_engg' as: 'interactions' or 'groupby' or 'target'
+                                """ %(module_type, version_number))
 ################################################################################
