@@ -3,8 +3,8 @@
 
 __title__ = "featurewiz"
 __author__ = "Ram Seshadri"
-__description__ = "Fast Feature Selection for any data set, any size"
+__description__ = "Fast Feature Engineering and Feature Selection for any data set, any size"
 __url__ = "https://github.com/Auto_ViML/featurewiz.git"
-__version__ = "0.0.7"
+__version__ = "0.0.19"
 __license__ = "Apache License 2.0"
 __copyright__ = "2020 Google"
